@@ -1,56 +1,22 @@
-from typing import Any
-from typing import Dict
 from typing import List
 from typing import Union
 from typing import Optional
 
 from .monitors import BasicMonitor
-from ...types import configs_type
+from ...schema import TqdmSettings
+from ...schema import OptimizerPack
+from ...schema import TrainerMonitor
+from ...schema import _IMetric
+from ...schema import _MultipleMetrics
+from ...schema import TrainerConfig
+from ...schema import TrainerCallback
 from ...trainer import Trainer
-from ...protocol import TqdmSettings
-from ...protocol import OptimizerPack
-from ...protocol import TrainerMonitor
-from ...protocol import _IMetric
-from ...protocol import _MultipleMetrics
-from ...protocol import TrainerCallback
 from .callbacks.general import _LogMetricsMsgCallback
 
 
-def make_trainer(
-    state_config: Optional[Dict[str, Any]] = None,
-    *,
-    workplace: str,
-    num_epoch: int = 40,
-    max_epoch: int = 1000,
-    fixed_epoch: Optional[int] = None,
-    fixed_steps: Optional[int] = None,
-    log_steps: Optional[int] = None,
-    valid_portion: float = 1.0,
-    amp: bool = False,
-    clip_norm: float = 0.0,
-    metric_names: Optional[Union[str, List[str]]] = None,
-    metric_configs: configs_type = None,
-    metric_weights: Optional[Dict[str, float]] = None,
-    use_losses_as_metrics: Optional[bool] = None,
-    loss_metrics_weights: Optional[Dict[str, float]] = None,
-    recompute_train_losses_in_eval: bool = True,
-    monitor_names: Optional[Union[str, List[str]]] = None,
-    monitor_configs: configs_type = None,
-    callback_names: Optional[Union[str, List[str]]] = None,
-    callback_configs: configs_type = None,
-    lr: Optional[float] = None,
-    optimizer_name: Optional[str] = None,
-    scheduler_name: Optional[str] = None,
-    optimizer_config: Optional[Dict[str, Any]] = None,
-    scheduler_config: Optional[Dict[str, Any]] = None,
-    update_scheduler_per_epoch: bool = False,
-    optimizer_settings: Optional[Dict[str, Dict[str, Any]]] = None,
-    use_zero: bool = False,
-    data_info_name: str = "data_info",
-    metrics_log_file: str = "metrics.txt",
-    finetune_config: Optional[Dict[str, Any]] = None,
-    tqdm_settings: Optional[Dict[str, Any]] = None,
-) -> Trainer:
+def make_trainer(config: TrainerConfig) -> Trainer:
+    state_config = config.state_config
+    log_steps = config.log_steps
     if state_config is None:
         state_config = {}
     if log_steps is not None:
@@ -58,6 +24,9 @@ def make_trainer(
         state_config.setdefault("snapshot_start_step", log_steps)
         state_config.setdefault("num_step_per_snapshot", log_steps)
     # metrics
+    metric_names = config.metric_names
+    metric_configs = config.metric_configs
+    metric_weights = config.metric_weights
     metrics: Optional[Union[_IMetric, _MultipleMetrics]]
     if metric_names is None:
         metrics = None
@@ -68,18 +37,23 @@ def make_trainer(
             metric_weights=metric_weights,
         )
     # monitor
+    monitor_names = config.monitor_names
+    monitor_configs = config.monitor_configs
     monitors: Optional[List[TrainerMonitor]]
     if monitor_names is None:
         monitors = None
     else:
         monitors = TrainerMonitor.make_multiple(monitor_names, monitor_configs)
     # callback
+    callback_names = config.callback_names
+    callback_configs = config.callback_configs
     callbacks: Optional[List[TrainerCallback]]
     if callback_names is None:
         callbacks = None
     else:
         callbacks = TrainerCallback.make_multiple(callback_names, callback_configs)
     # optimizer
+    optimizer_settings = config.optimizer_settings
     if optimizer_settings is None:
         optimizer_packs = None
     else:
@@ -98,10 +72,14 @@ def make_trainer(
                 )
             )
     # tqdm
+    tqdm_settings = config.tqdm_settings
     if tqdm_settings is None:
         tqdm_settings = {}
     use_tqdm = tqdm_settings.setdefault("use_tqdm", False)
     # epoch
+    max_epoch = config.max_epoch
+    num_epoch = config.num_epoch
+    fixed_epoch = config.fixed_epoch
     if fixed_epoch is not None:
         num_epoch = max_epoch = fixed_epoch
     if max_epoch < num_epoch:
@@ -115,28 +93,28 @@ def make_trainer(
         state_config,
         num_epoch=num_epoch,
         max_epoch=max_epoch,
-        fixed_steps=fixed_steps,
-        valid_portion=valid_portion,
-        amp=amp,
-        clip_norm=clip_norm,
+        fixed_steps=config.fixed_steps,
+        valid_portion=config.valid_portion,
+        amp=config.amp,
+        clip_norm=config.clip_norm,
         metrics=metrics,
-        use_losses_as_metrics=use_losses_as_metrics,
-        loss_metrics_weights=loss_metrics_weights,
-        recompute_train_losses_in_eval=recompute_train_losses_in_eval,
+        use_losses_as_metrics=config.use_losses_as_metrics,
+        loss_metrics_weights=config.loss_metrics_weights,
+        recompute_train_losses_in_eval=config.recompute_train_losses_in_eval,
         monitors=monitors,
         callbacks=callbacks,
-        lr=lr,
-        optimizer_name=optimizer_name,
-        scheduler_name=scheduler_name,
-        optimizer_config=optimizer_config,
-        scheduler_config=scheduler_config,
-        update_scheduler_per_epoch=update_scheduler_per_epoch,
+        lr=config.lr,
+        optimizer_name=config.optimizer_name,
+        scheduler_name=config.scheduler_name,
+        optimizer_config=config.optimizer_config,
+        scheduler_config=config.scheduler_config,
+        update_scheduler_per_epoch=config.update_scheduler_per_epoch,
         optimizer_packs=optimizer_packs,
-        use_zero=use_zero,
-        workplace=workplace,
-        data_info_name=data_info_name,
-        metrics_log_file=metrics_log_file,
-        finetune_config=finetune_config,
+        use_zero=config.use_zero,
+        workplace=config.workplace,
+        data_info_name=config.data_info_name,
+        metrics_log_file=config.metrics_log_file,
+        finetune_config=config.finetune_config,
         tqdm_settings=TqdmSettings(
             use_tqdm,
             tqdm_settings.setdefault("use_step_tqdm", use_tqdm),
